CFPRIME VALNAM                                                          VALNAM      1
C***********************************************************************RIGHTE      1
C*                                                                     *RIGHTE      2
C*        Extended Transient-Midterm Stability Program (ETMSP)         *RIGHTE      3
C*        ====================================================         *RIGHTE      4
C*                                                                     *RIGHTE      5
C*       Copyright (C) (1993) Electric Power Research Institute        *RIGHTE      6
C*                                                                     *RIGHTE      7
C* EPRI reserves all rights in the software and associated             *RIGHTE      8
C* documentation as delivered. The software and its associated         *RIGHTE      9
C* documention or any portion thereof may not be reproduced in any form*RIGHTE     10
C* whatsoever without the consent of EPRI, except as explicity provided*RIGHTE     11
C* for by license. Licensee shall submit a detailed description to EPRI*RIGHTE     12
C* of any changes or modifications to the software within two (2)      *RIGHTE     13
C* months after such changes or modifications are made. At EPRI's sole *RIGHTE     14
C* discretion, the software, as changed or modified, shall be given a  *RIGHTE     15
C* new designation sufficiently different from its then current        *RIGHTE     16
C* designation as to prevent mistake,confusion, or deception as between*RIGHTE     17
C* the current software as changed or modified.                        *RIGHTE     18
C*                                                                     *RIGHTE     19
C* A license under EPRI's rights in the software can be obtained       *RIGHTE     20
C* directly from EPRI.                                                 *RIGHTE     21
C*                                                                     *RIGHTE     22
C* This program and supporting materials may be independently available*RIGHTE     23
C* from Electric Power Software centre (EPSC) for an appropriate       *RIGHTE     24
C* distribution fee. The EPSC is a service of                          *RIGHTE     25
C*                                                                     *RIGHTE     26
C*                    Power Computing Company                          *RIGHTE     27
C*                    1930 Hi Line                                     *RIGHTE     28
C*                    Dallas, Tx 75207                                 *RIGHTE     29
C*                                                                     *RIGHTE     30
C* NEITHER EPRI, ANY MEMBER OF EPRI, NOR ANY PERSON OR  ORGANIZATION   *RIGHTE     31
C* ACTING ON BEHAVE OF THEM:                                           *RIGHTE     32
C*                                                                     *RIGHTE     33
C* 1. MAKE ANY WARRANTY OR REPRESENTATION WHATSOEVER, EXPRESS OR       *RIGHTE     34
C*    IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY OR FITNESS OR *RIGHTE     35
C*    ANY PURPOSE WITH RESPECT TO THE SOFTWARE OR ITS ASSOCIATED       *RIGHTE     36
C*    DOCUMENTATION; OR                                                *RIGHTE     37
C*                                                                     *RIGHTE     38
C* 2. ASSUMES ANY LIABILITY WHATSOEVER WITH RESPECT TO ANY USE OF THE  *RIGHTE     39
C*    SOFTWARE OR ITS ASSOCIATED DOCUMENTATION OR ANY PORTION THEREOF  *RIGHTE     40
C*    OR WITH RESPECT TO ANY DAMAGES WHICH MAY RESULT FROM SUCH USE.   *RIGHTE     41
C*                                                                     *RIGHTE     42
C* THIS NOTICE MAY NOT BE REMOVED FROM THE SOFTWARE BY ANY USER        *RIGHTE     43
C* THEREOF.                                                            *RIGHTE     44
C*                                                                     *RIGHTE     45
C***********************************************************************RIGHTE     46
      SUBROUTINE  VALNAM (NAME, NAMLEN, NAMTYP, VALID, DONE)            VALNAM      3
C---------------------------------------------------------------------  VALNAM      4
C                                                                       VALNAM      5
C               *****     VALNAM  ROUTINE   *****                       VALNAM      6
C                                                                       VALNAM      7
CD--------------------------------------------------------------------- VALNAM      8
CD                                                                      VALNAM      9
CD        PURPOSE:  Determines if the validity of the name, whether it  VALNAM     10
CD                 is a block name or a structure name.  If the name    VALNAM     11
CD                  is not valid, all associated information for this   VALNAM     12
CD                 block or structure will be ignored.                  VALNAM     13
CD                                                                      VALNAM     14
CD                                                                      VALNAM     15
CD        DEFINITION OF LOCAL VARIABLES:                                VALNAM     16
CD          (P)    DONE   -  test for end of input line                 VALNAM     17
CD                 JDOT   -  set if . occurs in name                    VALNAM     18
CD                  END    -  end of data for this udc block.           VALNAM     19
CD                  FOUND  -  indicates if data was found.              VALNAM     20
CD                 I      -  do loop index                              VALNAM     21
CD                 LEN1   -  length of prefix                           VALNAM     22
CD                 LEN2   -  length of suffix                           VALNAM     23
CD           (P)    NAMLEN -  length of character input data.           VALNAM     24
CD           (P)    NAME   -  name of the udc block.                    VALNAM     25
CD           (P)    NAMTYP -  type of name (either 'block', 'dumblk',   VALNAM     26
CD                           or 'struct')                               VALNAM     27
CD                 NEXT   -  pointer to next block                      VALNAM     28
CD                  SUBNAM -  subroutine name.                          VALNAM     29
CD          (P)    VALID  -  set if name is valid name                  VALNAM     30
CD                                                                      VALNAM     31
CD                                                                      VALNAM     32
CD        SUBROUTINES REQUIRED:  URGETC                                 VALNAM     33
CD                                                                      VALNAM     34
CD--------------------------------------------------------------------- VALNAM     35
      INCLUDE 'CNUNIT.INS'                                              VALNAM     36
      INCLUDE 'CNMSG.INS'                                               VALNAM     37
      INCLUDE 'PARX.INS'                                                VALNAM     38
      INCLUDE 'UDCA.INS'                                                VALNAM     39
      INCLUDE 'UDCH.INS'                                                VALNAM     40
      INCLUDE 'UDCI.INS'                                                VALNAM     41
C                                                                       VALNAM     42
      LOGICAL       END, FOUND, VALID, DONE                             VALNAM     43
C                                                                       VALNAM     44
      CHARACTER*72  NAME                                                VALNAM     45
      CHARACTER*20  SUBNAM                                              VALNAM     46
      CHARACTER*6   NAMTYP                                              VALNAM     47
C                                                                       VALNAM     48
C---------------------------------------------------------------------  VALNAM     49
C                                                                       VALNAM     50
      IF(SDBG)THEN                                                      VALNAM     51
         SUBNAM = 'VALNAM ROUTINE.'                                     VALNAM     52
      ELSE                                                              VALNAM     53
         SUBNAM = ' '                                                   VALNAM     54
      END IF                                                            VALNAM     55
C                                                                       VALNAM     56
C     Determine the format of the name.                                 VALNAM     57
C                                                                       VALNAM     58
      VALID = .TRUE.                                                    VALNAM     59
      LEN1 = 0                                                          VALNAM     60
      LEN2 = 0                                                          VALNAM     61
      JDOT = 0                                                          VALNAM     62
      DO 20 I = 1, 72                                                   VALNAM     63
         IF(NAME(I:I).EQ.'.')THEN                                       VALNAM     64
            JDOT = JDOT + 1                                             VALNAM     65
         ELSEIF(NAME(I:I) .NE. ' ')THEN                                 VALNAM     66
            IF(JDOT.EQ.0)THEN                                           VALNAM     67
               LEN1 = LEN1 + 1                                          VALNAM     68
            ELSE                                                        VALNAM     69
               LEN2 = LEN2 + 1                                          VALNAM     70
            END IF                                                      VALNAM     71
         END IF                                                         VALNAM     72
20    CONTINUE                                                          VALNAM     73
C                                                                       VALNAM     74
      NAMLEN = LEN1 + JDOT + LEN2                                       VALNAM     75
C                                                                       VALNAM     76
      IF(NAMTYP.EQ.'BLOCK ' .OR. NAMTYP.EQ.'DUMBLK')THEN                VALNAM     77
C                                                                       VALNAM     78
C        Check validity of block name.                                  VALNAM     79
C                                                                       VALNAM     80
         IF(DEFINE)THEN                                                 VALNAM     81
C                                                                       VALNAM     82
C           The only valid format for a block name defined in a         VALNAM     83
C           structure definition is  ".XXXXXXXX".                       VALNAM     84
C                                                                       VALNAM     85
            IF(JDOT.EQ.1)THEN                                           VALNAM     86
               IF(LEN1 .NE. 0)THEN                                      VALNAM     87
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM     88
                  WRITE(MSG(3),9002) NAME(1:NAMLEN)                     VALNAM     89
                  WRITE(MSG(2),9001)                                    VALNAM     90
                  WRITE(MSG(4),9003)                                    VALNAM     91
                  WRITE(MSG(5),9200)                                    VALNAM     92
                  CALL PRTMSG(5)                                        VALNAM     93
                  IERCNT = IERCNT + 1                                   VALNAM     94
                  VALID = .FALSE.                                       VALNAM     95
               ELSEIF(LEN2 .GT. 8)THEN                                  VALNAM     96
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM     97
                  WRITE(MSG(3),9004) NAME(1:NAMLEN)                     VALNAM     98
                  WRITE(MSG(2),9001)                                    VALNAM     99
                  WRITE(MSG(4),9005)                                    VALNAM    100
                  WRITE(MSG(5),9200)                                    VALNAM    101
                  CALL PRTMSG(5)                                        VALNAM    102
                  IERCNT = IERCNT + 1                                   VALNAM    103
                  VALID = .FALSE.                                       VALNAM    104
               END IF                                                   VALNAM    105
            ELSE                                                        VALNAM    106
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    107
                  WRITE(MSG(3),9002) NAME(1:NAMLEN)                     VALNAM    108
                  WRITE(MSG(2),9001)                                    VALNAM    109
                  WRITE(MSG(4),9003)                                    VALNAM    110
                  WRITE(MSG(5),9200)                                    VALNAM    111
                  CALL PRTMSG(5)                                        VALNAM    112
               IERCNT = IERCNT + 1                                      VALNAM    113
               VALID = .FALSE.                                          VALNAM    114
            END IF                                                      VALNAM    115
C                                                                       VALNAM    116
C                                                                       VALNAM    117
         ELSEIF(EXPAND)THEN                                             VALNAM    118
C                                                                       VALNAM    119
C           The only valid format for a block name in a structure that  VALNAM    120
C           is being expanded is  "YYYYYYYY.XXXXXXXX".                  VALNAM    121
C                                                                       VALNAM    122
            IF(JDOT.EQ.1)THEN                                           VALNAM    123
               IF(LEN1.EQ.0)THEN                                        VALNAM    124
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    125
                  WRITE(MSG(3),9002) NAME(1:NAMLEN)                     VALNAM    126
                  WRITE(MSG(2),9001)                                    VALNAM    127
                  WRITE(MSG(4),9006)                                    VALNAM    128
                  WRITE(MSG(5),9200)                                    VALNAM    129
                  CALL PRTMSG(5)                                        VALNAM    130
                  IERCNT = IERCNT + 1                                   VALNAM    131
                  VALID = .FALSE.                                       VALNAM    132
               ELSEIF(LEN2.EQ.0)THEN                                    VALNAM    133
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    134
                  WRITE(MSG(3),9007) NAME(1:NAMLEN)                     VALNAM    135
                  WRITE(MSG(2),9001)                                    VALNAM    136
                  WRITE(MSG(4),9008)                                    VALNAM    137
                  WRITE(MSG(5),9200)                                    VALNAM    138
                  CALL PRTMSG(5)                                        VALNAM    139
                  IERCNT = IERCNT + 1                                   VALNAM    140
                  VALID = .FALSE.                                       VALNAM    141
               ELSEIF(LEN1 .GT. 8 .OR. LEN2 .GT. 8)THEN                 VALNAM    142
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    143
                  WRITE(MSG(3),9002) NAME(1:NAMLEN)                     VALNAM    144
                  WRITE(MSG(2),9001)                                    VALNAM    145
                  WRITE(MSG(4),9009)                                    VALNAM    146
                  WRITE(MSG(5),9010)                                    VALNAM    147
                  WRITE(MSG(6),9200)                                    VALNAM    148
                  CALL PRTMSG(6)                                        VALNAM    149
                  IERCNT = IERCNT + 1                                   VALNAM    150
                  VALID = .FALSE.                                       VALNAM    151
               END IF                                                   VALNAM    152
            ELSE                                                        VALNAM    153
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    154
                  WRITE(MSG(3),9007) NAME(1:NAMLEN)                     VALNAM    155
                  WRITE(MSG(2),9001)                                    VALNAM    156
                  WRITE(MSG(4),9008)                                    VALNAM    157
                  WRITE(MSG(5),9200)                                    VALNAM    158
                  CALL PRTMSG(5)                                        VALNAM    159
               IERCNT = IERCNT + 1                                      VALNAM    160
               VALID = .FALSE.                                          VALNAM    161
            END IF                                                      VALNAM    162
C                                                                       VALNAM    163
C                                                                       VALNAM    164
         ELSE                                                           VALNAM    165
C                                                                       VALNAM    166
C           The only valid format for a block name not in a structure isVALNAM    167
C           "YYYYYYYY".                                                 VALNAM    168
C                                                                       VALNAM    169
            IF(JDOT.EQ.0)THEN                                           VALNAM    170
               IF(LEN1 .GT. 8)THEN                                      VALNAM    171
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    172
                  WRITE(MSG(3),9004) NAME(1:NAMLEN)                     VALNAM    173
                  WRITE(MSG(2),9001)                                    VALNAM    174
                  WRITE(MSG(4),9012)                                    VALNAM    175
                  WRITE(MSG(5),9200)                                    VALNAM    176
                  CALL PRTMSG(5)                                        VALNAM    177
                  IERCNT = IERCNT + 1                                   VALNAM    178
                  VALID = .FALSE.                                       VALNAM    179
               END IF                                                   VALNAM    180
            ELSE                                                        VALNAM    181
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    182
                  WRITE(MSG(3),9002) NAME(1:NAMLEN)                     VALNAM    183
                  WRITE(MSG(2),9001)                                    VALNAM    184
                  WRITE(MSG(4),9014)                                    VALNAM    185
                  WRITE(MSG(5),9200)                                    VALNAM    186
                  CALL PRTMSG(5)                                        VALNAM    187
               IERCNT = IERCNT + 1                                      VALNAM    188
               VALID = .FALSE.                                          VALNAM    189
            END IF                                                      VALNAM    190
C                                                                       VALNAM    191
         END IF                                                         VALNAM    192
C                                                                       VALNAM    193
C                                                                       VALNAM    194
      ELSE                                                              VALNAM    195
C                                                                       VALNAM    196
C        Check validity of structure name.                              VALNAM    197
C                                                                       VALNAM    198
         IF(JDOT .NE. 0)THEN                                            VALNAM    199
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    200
                  WRITE(MSG(3),9016) NAME(1:NAMLEN)                     VALNAM    201
                  WRITE(MSG(2),9015)                                    VALNAM    202
                  WRITE(MSG(4),9017)                                    VALNAM    203
                  WRITE(MSG(5),9201)                                    VALNAM    204
                  CALL PRTMSG(5)                                        VALNAM    205
            IERCNT = IERCNT + 1                                         VALNAM    206
            VALID = .FALSE.                                             VALNAM    207
         ELSEIF(NAMLEN .GT. 8)THEN                                      VALNAM    208
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    209
                  WRITE(MSG(3),9004) NAME(1:NAMLEN)                     VALNAM    210
                  WRITE(MSG(2),9015)                                    VALNAM    211
                  WRITE(MSG(4),9012)                                    VALNAM    212
                  WRITE(MSG(5),9201)                                    VALNAM    213
                  CALL PRTMSG(5)                                        VALNAM    214
            IERCNT = IERCNT + 1                                         VALNAM    215
            VALID = .FALSE.                                             VALNAM    216
         END IF                                                         VALNAM    217
      END IF                                                            VALNAM    218
C                                                                       VALNAM    219
C---------------------------------------------------------------------  VALNAM    220
C                                                                       VALNAM    221
C     Check for uniqueness of the block name or structure name if it    VALNAM    222
C     is valid.                                                         VALNAM    223
C                                                                       VALNAM    224
      IF(VALID)THEN                                                     VALNAM    225
C                                                                       VALNAM    226
         IF(NAMTYP.EQ.'BLOCK ' .OR. NAMTYP.EQ.'DUMBLK')THEN             VALNAM    227
C                                                                       VALNAM    228
            IF(DEFINE)THEN                                              VALNAM    229
C                                                                       VALNAM    230
C              Check if this block name has not already been defined    VALNAM    231
C              in this structure.                                       VALNAM    232
C                                                                       VALNAM    233
               NEXT = ISRTOP(NMSTRC)                                    VALNAM    234
40             IF(NEXT.EQ.0 .OR. .NOT. VALID) GOTO 60                   VALNAM    235
                  IF(BKNAME(NEXT).EQ.NAME)THEN                          VALNAM    236
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    237
                  WRITE(MSG(3),9020) NAME(1:NAMLEN)                     VALNAM    238
                  WRITE(MSG(2),9001)                                    VALNAM    239
                  WRITE(MSG(4),9021)                                    VALNAM    240
                  WRITE(MSG(5),9022)                                    VALNAM    241
                  CALL PRTMSG(5)                                        VALNAM    242
                     IERCNT = IERCNT + 1                                VALNAM    243
                     VALID = .FALSE.                                    VALNAM    244
                  ELSE                                                  VALNAM    245
                     NEXT = IBKNEX(NEXT)                                VALNAM    246
                  END IF                                                VALNAM    247
                  GOTO 40                                               VALNAM    248
60             CONTINUE                                                 VALNAM    249
C                                                                       VALNAM    250
            ELSE                                                        VALNAM    251
C                                                                       VALNAM    252
C              Check if this block name has already been defined in     VALNAM    253
C              the udc system.                                          VALNAM    254
C                                                                       VALNAM    255
               DO 80 I = 1, IUDC                                        VALNAM    256
                  IF(UDNAME(I).EQ.NAME)THEN                             VALNAM    257
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    258
                  WRITE(MSG(3),9020) NAME(1:NAMLEN)                     VALNAM    259
                  WRITE(MSG(2),9001)                                    VALNAM    260
                  WRITE(MSG(4),9022)                                    VALNAM    261
                  CALL PRTMSG(4)                                        VALNAM    262
                     IERCNT = IERCNT + 1                                VALNAM    263
                     VALID = .FALSE.                                    VALNAM    264
                  END IF                                                VALNAM    265
80             CONTINUE                                                 VALNAM    266
            END IF                                                      VALNAM    267
C                                                                       VALNAM    268
C                                                                       VALNAM    269
         ELSE                                                           VALNAM    270
C                                                                       VALNAM    271
C           Check if this structure name has already been added         VALNAM    272
C           as a subtype name for a structure block.                    VALNAM    273
C                                                                       VALNAM    274
            DO 100 I = 1, NMSTRC                                        VALNAM    275
               IF(SBSTRC(I).EQ.NAME)THEN                                VALNAM    276
                  WRITE (MSG(1),9000) SUBNAM                            VALNAM    277
                  WRITE(MSG(3),9025) NAME(1:NAMLEN)                     VALNAM    278
                  WRITE(MSG(2),9024)                                    VALNAM    279
                  WRITE(MSG(4),9026)                                    VALNAM    280
                  WRITE(MSG(5),9027)                                    VALNAM    281
                  CALL PRTMSG(5)                                        VALNAM    282
                  IERCNT = IERCNT + 1                                   VALNAM    283
                  VALID = .FALSE.                                       VALNAM    284
               END IF                                                   VALNAM    285
100         CONTINUE                                                    VALNAM    286
         END IF                                                         VALNAM    287
      END IF                                                            VALNAM    288
C                                                                       VALNAM    289
C---------------------------------------------------------------------  VALNAM    290
C                                                                       VALNAM    291
C                                                                       VALNAM    292
      IF(.NOT. VALID)THEN                                               VALNAM    293
C                                                                       VALNAM    294
         IF(NAMTYP.EQ.'BLOCK ')THEN                                     VALNAM    295
C                                                                       VALNAM    296
C           Ignore data for this block.                                 VALNAM    297
C                                                                       VALNAM    298
            IF(EXPAND)THEN                                              VALNAM    299
               EXPAND = .FALSE.                                         VALNAM    300
            END IF                                                      VALNAM    301
120         IF(ENDBLK .OR. EOF) GOTO 140                                VALNAM    302
               CALL URGETC (NAME, FOUND)                                VALNAM    303
               GOTO 120                                                 VALNAM    304
140         CONTINUE                                                    VALNAM    305
C                                                                       VALNAM    306
         ELSEIF(NAMTYP.EQ.'STRUCT ')THEN                                VALNAM    307
C                                                                       VALNAM    308
C           Ignore data for this structure definition.                  VALNAM    309
C                                                                       VALNAM    310
            END = .FALSE.                                               VALNAM    311
160         IF(END .OR. EOF .OR. DONE) GOTO 180                         VALNAM    312
               CALL URGETC (NAME, FOUND)                                VALNAM    313
               IF(NAME.EQ.'END STRUCTURE')THEN                          VALNAM    314
                  END = .TRUE.                                          VALNAM    315
               ELSEIF(NAME.EQ.'ENDUDC')THEN                             VALNAM    316
                  DONE = .TRUE.                                         VALNAM    317
               END IF                                                   VALNAM    318
               GOTO 160                                                 VALNAM    319
180         CONTINUE                                                    VALNAM    320
         END IF                                                         VALNAM    321
C                                                                       VALNAM    322
      END IF                                                            VALNAM    323
C                                                                       VALNAM    324
C                                                                       VALNAM    325
C---------------------------------------------------------------------  VALNAM    326
C                                                                       VALNAM    327
      RETURN                                                            VALNAM    328
C                                                                       VALNAM    329
C---------------------------------------------------------------------  VALNAM    330
C                                                                       VALNAM    331
9000  FORMAT(' *** ERROR', 5X, A)                                       VALNAM    332
9001  FORMAT(11X                                                        VALNAM    333
     *,'DURING THE READING OF THE UDC BLOCKS, THE BLOCK NAME')          VALNAM    334
9002  FORMAT(11X,'"',A,'" HAS AN INVALID FORMAT.')                      VALNAM    335
9003  FORMAT(11X,'A BLOCK DEFINED IN A STRUCTURE MUST BE ".YYYYYYYY"')  VALNAM    336
9200  FORMAT(11X,'INFORMATION FOR THIS BLOCK WILL BE IGNORED.')         VALNAM    337
9004  FORMAT(11X,'"', A, '" HAS AN INVALID LENGTH.')                    VALNAM    338
9005  FORMAT(11X,'A MAXIMUM OF 8 CHARACTERS CAN FOLLOW A PERIOD.')      VALNAM    339
9006  FORMAT(11X                                                        VALNAM    340
     *,'ONLY A BLOCK DEFINED IN A STRUCTURE CAN BE ".YYYYYYYY"')        VALNAM    341
9007  FORMAT(11X                                                        VALNAM    342
     *,'"',A,'" HAS AN INVALID FORMAT.  A BLOCK NAME CREATED')          VALNAM    343
9008  FORMAT(11X                                                        VALNAM    344
     *,'BY EXPANDING A STRUCTURE MUST BE "XXXXXXXX.YYYYYYYY"')          VALNAM    345
9009  FORMAT(11X                                                        VALNAM    346
     *,'A BLOCK IN A STRUCTURE SHOULD BE "XXXXXXXX.YYYYYYYY"')          VALNAM    347
9010  FORMAT(11X,'WHERE EACH PART DOES NOT EXCEED 8 CHARACTERS')        VALNAM    348
9012  FORMAT(11X,'THE LENGTH EXCEEDS 8 CHARACTERS.')                    VALNAM    349
9014  FORMAT(11X,'ONLY BLOCKS IN A STRUCTURE CAN CONTAIN A PERIOD.')    VALNAM    350
9015  FORMAT(11X                                                        VALNAM    351
     *,'DURING THE DEFINTION OF A STRUCTURE, THE STRUCTURE NAME')       VALNAM    352
9016  FORMAT(11X,'"',A,'" IS INVALID.')                                 VALNAM    353
9017  FORMAT(11X,'THE NAME CANNOT CONTAIN ANY PERIODS.')                VALNAM    354
9201  FORMAT(11X,'THIS STRUCTURE DEFINITION WILL BE IGNORED.')          VALNAM    355
9020  FORMAT(11X,'"', A, '" IS NOT UNIQUE.')                            VALNAM    356
9021  FORMAT(11X                                                        VALNAM    357
     *,'THIS BLOCK HAS ALREADY BEEN DEFINED IN THIS STRUCTURE.')        VALNAM    358
9022  FORMAT(11X,'THE DATA FOR THE DUPLICATE BLOCK IS IGNORED.')        VALNAM    359
9024  FORMAT(11X                                                        VALNAM    360
     *,'DURING THE READING OF THE UDC BLOCKS, THE STRUCTURE')           VALNAM    361
9025  FORMAT(11X,'SUBTYPE "', A, '" IS NOT UNIQUE.')                    VALNAM    362
9026  FORMAT(11X                                                        VALNAM    363
     *,'MORE THAN ONE DEFINITION EXISTS FOR THIS STRUCTURE NAME.')      VALNAM    364
9027  FORMAT(11X,'THIS STRUCTURE DEFINITION WILL BE IGNORED.')          VALNAM    365
C                                                                       VALNAM    366
C---------------------------------------------------------------------  VALNAM    367
C                                                                       VALNAM    368
      END                                                               VALNAM    369
